@@ -1,5 +1,5 @@
 /*  XMMS2 - X Music Multiplexer System
- *  Copyright (C) 2003-2011 XMMS2 Team
+ *  Copyright (C) 2003-2023 XMMS2 Team
  *
  *  PLUGINS ARE NOT CONSIDERED TO BE DERIVED WORK !!!
  *
@@ -18,9 +18,10 @@
 #define __XMMS_STRLIST_H__
 
 #include <stdarg.h>
+#include <xmmsc/xmmsc_compiler.h>
 
 char **xmms_valist_to_strlist (const char *first, va_list ap);
-char **xmms_vargs_to_strlist (const char *first, ...);
+char **xmms_vargs_to_strlist (const char *first, ...) XMMS_SENTINEL(0);
 int xmms_strlist_len (char **data);
 void xmms_strlist_destroy (char **data);
 char **xmms_strlist_prepend_copy (char **data, char *newstr);
