@@ -1,5 +1,5 @@
 /*  XMMS2 - X Music Multiplexer System
- *  Copyright (C) 2003-2009 XMMS2 Team
+ *  Copyright (C) 2003-2023 XMMS2 Team
  *
  *  PLUGINS ARE NOT CONSIDERED TO BE DERIVED WORK !!!
  *
@@ -27,6 +27,38 @@
 
 #include <boost/scoped_ptr.hpp>
 
+// Fix for libcxx 19 
+namespace std {
+    template<>
+    struct char_traits<unsigned char> {
+        typedef unsigned char char_type;
+        typedef int int_type;
+        typedef streamoff off_type;
+        typedef streampos pos_type;
+        typedef mbstate_t state_type;
+
+        static void assign(char_type& c1, const char_type& c2) { c1 = c2; }
+        static bool eq(const char_type& c1, const char_type& c2) { return c1 == c2; }
+        static bool lt(const char_type& c1, const char_type& c2) { return c1 < c2; }
+        
+        static int compare(const char_type* s1, const char_type* s2, size_t n) {
+            return memcmp(s1, s2, n);
+        }
+        
+        static size_t length(const char_type* s) {
+            return strlen(reinterpret_cast<const char*>(s));
+        }
+        
+        static char_type* copy(char_type* s1, const char_type* s2, size_t n) {
+            return reinterpret_cast<char_type*>(memcpy(s1, s2, n));
+        }
+        
+        static char_type* move(char_type* s1, const char_type* s2, size_t n) {
+            return reinterpret_cast<char_type*>(memmove(s1, s2, n));
+        }
+    };
+}
+
 namespace Xmms
 {
 
